package core.api.controller;

import core.api.models.timemanager.history.WorkingStatus;
import core.entities.timemanager.AbstractSchedule;
import core.services.TaskScheduleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.time.Duration;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.LocalTime;
import java.util.List;

@CrossOrigin(origins = "*", maxAge = 3600)
@RestController
@RequestMapping("/api")
public class StatisticController {

    @Autowired private TaskScheduleService taskScheduleService;

    @GetMapping("/history/workingStatus")
    public ResponseEntity<?> getWorkingStatus() {
        boolean missedSchedules = !taskScheduleService.getAllMissedSchedulesOfUser(SecurityContextHolder.getContext().getAuthentication().getName()).isEmpty();
        List<AbstractSchedule> executedSchedules = taskScheduleService.getActiveSchedulesOfToday(SecurityContextHolder.getContext().getAuthentication().getName());
        int activeTime = 0;
        for(AbstractSchedule schedule : executedSchedules) {
            if(schedule.getStartTime().toLocalDate().isBefore(LocalDate.now())) {
                activeTime += (int) Duration.between(LocalDateTime.of(LocalDate.now(), LocalTime.MIDNIGHT), schedule.getStopTime()).toMinutes();
            } else {
                activeTime += (int) Duration.between(schedule.getStartTime(), schedule.getStopTime()).toMinutes();
            }
        }

        return ResponseEntity.ok(new WorkingStatus(missedSchedules, activeTime));
    }
}
